@@ -53,7 +53,7 @@ type Deb struct {
 	Filename     string `control:"Filename"`
 	FromAppStore bool
 	PackageKind  string
-	Command      string
+	Command      []string
 	Sources      []comm.Source
 	Build        []string
 }
@@ -78,14 +78,14 @@ func (d *Deb) GetPackageUrl(source, distro, arch string) string {
 		"-ignore-signatures",
 		"-architectures=" + arch,
 		"-filter=" + d.Name,
-		d.Name,
+		distro,
 		source,
 		distro,
 	}
 
 	cmd.Run(root, args, cmd.GetContext() == nil)
 
-	d.GetPackageList()
+	d.GetPackageList(distro)
 	if len(d.Sources) > 0 {
 		return d.Sources[0].Url
 	} else {
@@ -252,6 +252,7 @@ func (d *Deb) ResolveDepends(source, distro string, withDep bool) {
 		}
 	}
 	filter = strings.Join(result, ",")
+
 	// 删除掉aptly缓存的内容
 	aptlyCache := comm.AptlyCachePath()
 	if ret, _ := fs.CheckFileExits(aptlyCache); ret {
@@ -287,19 +288,17 @@ func (d *Deb) ResolveDepends(source, distro string, withDep bool) {
 	}
 
 	args = append(args, []string{
-		d.Name,
+		distro,
 		source,
 		distro,
 	}...)
 
 	cmd.Run(root, args, cmd.GetContext() == nil)
 
-	d.GetPackageList()
+	d.GetPackageList(distro)
 }
 
 func (d *Deb) GenerateBuildScript() {
-	execFile := "start.sh"
-
 	d.Build = append(d.Build, "#>>> auto generate by ll-pica begin")
 
 	// 设置 linglong/sources 目录
@@ -367,7 +366,7 @@ func (d *Deb) GenerateBuildScript() {
 			modiDesktopPath := "$SOURCES" + desktop[index+len(comm.LlSourceDir):]
 			d.Build = append(d.Build, []string{
 				"# modify desktop, Exec and Icon should not contanin absolut paths",
-				fmt.Sprintf("sed -i '/Exec*/c\\Exec=%s' %s", execFile, modiDesktopPath),
+				fmt.Sprintf("sed -i '/Exec*/c\\Exec=%s' %s", execLine, modiDesktopPath),
 				fmt.Sprintf("sed -i '/Icon*/c\\Icon=%s' %s", iconValue, modiDesktopPath),
 			}...)
 		}
@@ -436,28 +435,27 @@ func (d *Deb) GenerateBuildScript() {
 		"    cp -rP $DATA_LIST_DIR/usr/* $PREFIX 2>/dev/null || true",
 		"done < \"$DEPS_LIST\"",
 		"rm -r $OUT_DIR || true", // # 清理临时目录
-		"# use a script as program",
-		fmt.Sprintf("echo \"#!/usr/bin/env bash\" > %s", execFile),
-		fmt.Sprintf("echo \"%s\" >> %s", execLine, execFile),
 	}...)
 
 	d.Build = append(d.Build, []string{
+		"",
 		"install -d $PREFIX/share",
 		"install -d $PREFIX/bin",
 		"install -d $PREFIX/lib",
-		fmt.Sprintf("install -m 0755 %s $PREFIX/bin", execFile),
 	}...)
 
 	if d.FromAppStore {
 		d.Build = append(d.Build, []string{
+			"",
 			"# move files",
 			fmt.Sprintf("cp -r $SOURCES/%s/opt/apps/%s/entries/* $PREFIX/share", d.Name, realPackageName),
-			fmt.Sprintf("cp -r $SOURCES/%s/opt/apps/%s/files/* $PREFIX", d.Name, realPackageName),
+			fmt.Sprintf("cp -rf $SOURCES/%s/opt/apps/%s/files/* $PREFIX", d.Name, realPackageName),
 		}...)
 	}
 
 	if _, err := os.ReadDir(debDirPath + "/usr"); err == nil {
 		d.Build = append(d.Build, []string{
+			"",
 			"# move files",
 			fmt.Sprintf("cp -r $SOURCES/%s/usr/* $PREFIX", d.Name),
 		}...)
@@ -465,15 +463,15 @@ func (d *Deb) GenerateBuildScript() {
 
 	d.Build = append(d.Build, "#>>> auto generate by ll-pica end")
 
-	d.Command = fmt.Sprintf("/opt/apps/%s/files/bin/%s", d.Id, execFile)
+	d.Command = strings.Split(execLine, " ")
 }
 
 // 获取 deb 包
-func (d *Deb) GetPackageList() {
+func (d *Deb) GetPackageList(distro string) {
 	context := cmd.GetContext()
 	defer context.Shutdown()
 	collectionFactory := context.NewCollectionFactory()
-	repo, err := collectionFactory.RemoteRepoCollection().ByName(d.Name)
+	repo, err := collectionFactory.RemoteRepoCollection().ByName(distro)
 
 	if err != nil {
 		log.Logger.Errorf("unable to update: %s", err)
